import{g as c,f as g,r as p,b as u,j as d,c as f,d as m,s as D}from"./render-D1ZqzUbP.js";function x(s){return c("MuiDialogActions",s)}g("MuiDialogActions",["root","spacing"]);const y=s=>{const{classes:t,disableSpacing:o}=s;return m({root:["root",!o&&"spacing"]},x,t)},A=D("div",{name:"MuiDialogActions",slot:"Root",overridesResolver:(s,t)=>{const{ownerState:o}=s;return[t.root,!o.disableSpacing&&t.spacing]}})({display:"flex",alignItems:"center",padding:8,justifyContent:"flex-end",flex:"0 0 auto",variants:[{props:({ownerState:s})=>!s.disableSpacing,style:{"& > :not(style) ~ :not(style)":{marginLeft:8}}}]}),S=p.forwardRef(function(t,o){const a=u({props:t,name:"MuiDialogActions"}),{className:i,disableSpacing:n=!1,...l}=a,e={...a,disableSpacing:n},r=y(e);return d.jsx(A,{className:f(r.root,i),ownerState:e,ref:o,...l})});export{S as D};
//# sourceMappingURL=DialogActions-JiHQNj-t.js.map
