import{a as x,j as r,u as c,B as t,T as l}from"./render-D1ZqzUbP.js";import{L as d}from"./Layout-83ehEAk0.js";import{A as o}from"./Alert-M7jUzTjE.js";import{B as h}from"./Button-DJ_uYab0.js";import"./Container-vcG9JMyV.js";import"./Link-4dUp4u44.js";const p=()=>{const{successMessage:a,confirmationMessage:s,confirmUrl:i,errorMessage:e,ref:n,localeMessages:m}=c();return r.jsx(d,{children:!e&&!s?r.jsx(o,{severity:"success",sx:{maxWidth:800,margin:"0 auto",backgroundColor:"background.light"},children:a}):s?r.jsxs(t,{sx:{my:6},children:[r.jsx(l,{variant:"h6",align:"center",sx:{mt:4,color:"text.primary"},children:s})," ",r.jsx(t,{mt:6,sx:{textAlign:"center"},children:r.jsx(h,{href:i,variant:"contained",mt:2,sx:{mx:"auto",px:3,fontSize:"1rem"},children:m.Confirm})})]}):r.jsxs(o,{severity:"error",sx:{maxWidth:800,margin:"20px auto"},children:[e," (ref: ",n,")"]})})};x({children:r.jsx(p,{})});
//# sourceMappingURL=command_result-DBgI2zhG.js.map
