import{g as l,f as i,r as c,b as p,j as u,c as x,d as C,s as g,T as d,S as m}from"./render-D1ZqzUbP.js";function D(t){return l("MuiDialogContentText",t)}i("MuiDialogContentText",["root"]);const T=t=>{const{classes:o}=t,s=C({root:["root"]},D,o);return{...o,...s}},y=g(d,{shouldForwardProp:t=>m(t)||t==="classes",name:"MuiDialogContentText",slot:"Root"})({}),w=c.forwardRef(function(o,e){const s=p({props:o,name:"MuiDialogContentText"}),{children:f,className:r,...a}=s,n=T(a);return u.jsx(y,{component:"p",variant:"body1",color:"textSecondary",ref:e,ownerState:a,className:x(n.root,r),...s,classes:n})});export{w as D};
//# sourceMappingURL=DialogContentText-BSyscD7T.js.map
