import{r as h,j as W,c as k,a4 as v,E as c,H as R,d as G,aa as $,g as M,b as P,s as S}from"./render-D1ZqzUbP.js";const T=$(),j=v("div",{name:"MuiContainer",slot:"Root",overridesResolver:(a,s)=>{const{ownerState:o}=a;return[s.root,s[`maxWidth${c(String(o.maxWidth))}`],o.fixed&&s.fixed,o.disableGutters&&s.disableGutters]}}),y=a=>R({props:a,name:"MuiContainer",defaultTheme:T}),E=(a,s)=>{const o=i=>M(s,i),{classes:u,fixed:p,disableGutters:l,maxWidth:t}=a,e={root:["root",t&&`maxWidth${c(String(t))}`,p&&"fixed",l&&"disableGutters"]};return G(e,o,u)};function L(a={}){const{createStyledComponent:s=j,useThemeProps:o=y,componentName:u="MuiContainer"}=a,p=s(({theme:t,ownerState:e})=>({width:"100%",marginLeft:"auto",boxSizing:"border-box",marginRight:"auto",...!e.disableGutters&&{paddingLeft:t.spacing(2),paddingRight:t.spacing(2),[t.breakpoints.up("sm")]:{paddingLeft:t.spacing(3),paddingRight:t.spacing(3)}}}),({theme:t,ownerState:e})=>e.fixed&&Object.keys(t.breakpoints.values).reduce((i,r)=>{const d=r,n=t.breakpoints.values[d];return n!==0&&(i[t.breakpoints.up(d)]={maxWidth:`${n}${t.breakpoints.unit}`}),i},{}),({theme:t,ownerState:e})=>({...e.maxWidth==="xs"&&{[t.breakpoints.up("xs")]:{maxWidth:Math.max(t.breakpoints.values.xs,444)}},...e.maxWidth&&e.maxWidth!=="xs"&&{[t.breakpoints.up(e.maxWidth)]:{maxWidth:`${t.breakpoints.values[e.maxWidth]}${t.breakpoints.unit}`}}}));return h.forwardRef(function(e,i){const r=o(e),{className:d,component:n="div",disableGutters:m=!1,fixed:b=!1,maxWidth:f="lg",classes:N,...g}=r,x={...r,component:n,disableGutters:m,fixed:b,maxWidth:f},C=E(x,u);return W.jsx(p,{as:n,ownerState:x,className:k(C.root,d),ref:i,...g})})}const z=L({createStyledComponent:S("div",{name:"MuiContainer",slot:"Root",overridesResolver:(a,s)=>{const{ownerState:o}=a;return[s.root,s[`maxWidth${c(String(o.maxWidth))}`],o.fixed&&s.fixed,o.disableGutters&&s.disableGutters]}}),useThemeProps:a=>P({props:a,name:"MuiContainer"})});export{z as C};
//# sourceMappingURL=Container-vcG9JMyV.js.map
