{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-D1ZqzUbP.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Layout-83ehEAk0.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-M7jUzTjE.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-DJ_uYab0.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-vcG9JMyV.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-4dUp4u44.js">
    <script type="module" crossorigin src="/static/assets/command_result-DBgI2zhG.js"></script>
    <script>
        (() => {
            const appContextScript = document.getElementById('app-context');
            if (!appContextScript) {
                return;
            }

            try {
                const appContext = JSON.parse(appContextScript.textContent || '{}');
                if (appContext.closeWindow === true) {
                    window.setTimeout(() => {
                        window.close();
                    }, 1200);
                }
            } catch (_) {
                return;
            }
        })();
    </script>
{% endblock %}
