{% extends "personalised/base.html" %}

{% block head_script %}
    <style>
        @media print {
            @page {
                size: A4 landscape;
                margin: 0;
            }
            body {
                padding: 0;
                margin: 0;
            }
        }
    </style>
    <link rel="modulepreload" crossorigin href="/static/assets/render-D1ZqzUbP.js">
    <link rel="modulepreload" crossorigin href="/static/assets/WorkspacePremium-oZlDKw5g.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-M7jUzTjE.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grid-BihMtcd8.js">
    <link rel="modulepreload" crossorigin href="/static/assets/isMuiElement-BcEQvMml.js">
    <script type="module" crossorigin src="/static/assets/certificate-hClzNCkC.js"></script>
{% endblock %}
