{% extends "platform/base.html" %}

{% block extra_head %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-D1ZqzUbP.js">
    <link rel="modulepreload" crossorigin href="/static/assets/LinearProgress-a_GyCmbh.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Base-Qt2-pbvB.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Delete-BKYo-wX-.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Edit-Dg4av1tV.js">
    <link rel="modulepreload" crossorigin href="/static/assets/utils-VIUIl18e.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Grid-BihMtcd8.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-DJ_uYab0.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-aanaDG86.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-C1XOL3mQ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Select-Ht3nAO4Q.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-4dUp4u44.js">
    <link rel="modulepreload" crossorigin href="/static/assets/isMuiElement-BcEQvMml.js">
    <script type="module" crossorigin src="/static/assets/platform_organization-x2xE8e6i.js"></script>
{% endblock %}
