{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-D1ZqzUbP.js">
    <link rel="modulepreload" crossorigin href="/static/assets/WorkspacePremium-oZlDKw5g.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-vcG9JMyV.js">
    <link rel="modulepreload" crossorigin href="/static/assets/TextField-B6uk33js.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-M7jUzTjE.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-DJ_uYab0.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Select-Ht3nAO4Q.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-C1XOL3mQ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/isMuiElement-BcEQvMml.js">
    <script type="module" crossorigin src="/static/assets/certtificate_form-5xL3AlGn.js"></script>
{% endblock %}
