import{u as a,j as e,T as s,B as l}from"./render-D1ZqzUbP.js";import{C as c}from"./Container-vcG9JMyV.js";import{B as n}from"./Button-DJ_uYab0.js";const p=({content:r,onDelete:o,onCancel:i})=>{const{localeMessages:t}=a();return e.jsxs(c,{sx:{padding:4,textAlign:"center"},children:[e.jsx(s,{variant:"h6",gutterBottom:!0,children:t.delete_content_confirmation.replace("CONTENT_TITLE",r.title)}),e.jsxs(l,{sx:{marginTop:2},children:[e.jsx(n,{variant:"contained",color:"error",onClick:()=>o(r.id),sx:{marginRight:2},children:t.delete}),e.jsx(n,{variant:"outlined",onClick:i,children:t.cancel})]})]})};export{p as default};
//# sourceMappingURL=DeleteContentForm-CMy5CfgR.js.map
