import{a0 as n,u,j as p}from"./render-D1ZqzUbP.js";import{T as d}from"./TextField-B6uk33js.js";const c=n.forwardRef(({label:e,value:o,onChange:i,error:l,helperText:s,sx:a={},...x},t)=>{const{direction:r}=u();return console.log("RequiredTextField rendered, ref:",t),p.jsx(d,{ref:t,label:e,value:o,onChange:i,error:l,helperText:s,required:!0,sx:{...a,label:{right:r==="rtl"?"25px":"auto",left:r==="rtl"?"auto":0,"&.MuiInputLabel-shrink":{right:r==="rtl"?"30px":"auto",transformOrigin:r==="rtl"?"top right":"top left",left:r==="rtl"?"auto":0}}},slotProps:{formHelperText:{sx:{color:"errorText.main",marginLeft:0}}},...x,dir:r})});export{c as R};
//# sourceMappingURL=RequiredTextField-CyIv_v4F.js.map
