import{H as h,J as o,K as t,i as a,j as m}from"./render-D1ZqzUbP.js";function r({props:e,name:s}){return h({props:e,name:s,defaultTheme:o,themeId:t})}const n=a(m.jsx("path",{fillRule:"evenodd",d:"M13 9.5h5v-2h-5zm0 7h5v-2h-5zm6 4.5H5c-1.1 0-2-.9-2-2V5c0-1.1.9-2 2-2h14c1.1 0 2 .9 2 2v14c0 1.1-.9 2-2 2M6 11h5V6H6zm1-4h3v3H7zM6 18h5v-5H6zm1-4h3v3H7z"}));export{n as B,r as u};
//# sourceMappingURL=Ballot-B0TQ-4cv.js.map
