import{j as o,$ as n,B as e,T as t}from"./render-D1ZqzUbP.js";import{C as i}from"./Container-vcG9JMyV.js";import{L as s}from"./Link-4dUp4u44.js";const x=({children:a})=>o.jsxs(o.Fragment,{children:[o.jsx(n,{styles:r=>({body:{margin:0,padding:0,backgroundColor:r.palette.background.dark,color:r.palette.text.primary}})}),o.jsx(i,{sx:{backgroundColor:"background.paper",padding:4,marginTop:4,borderRadius:2,boxShadow:2},children:a}),o.jsx(e,{component:"footer",sx:{position:"fixed",bottom:0,right:16,padding:1,zIndex:1e3,backgroundColor:"transparent"},children:o.jsxs(t,{variant:"caption",sx:{color:"text.secondary",fontSize:"0.7rem",opacity:.8},children:["Powered by"," ",o.jsx(s,{href:"https://github.com/AvaCodeSolutions/django-email-learning",target:"_blank",rel:"noopener noreferrer",sx:{color:"primary.main",textDecoration:"none","&:hover":{textDecoration:"underline"}},children:"Django Email Learning"})]})})]});export{x as L};
//# sourceMappingURL=Layout-83ehEAk0.js.map
