{% extends "personalised/base.html" %}

{% block head_script %}
    <link rel="modulepreload" crossorigin href="/static/assets/render-D1ZqzUbP.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Layout-83ehEAk0.js">
    <link rel="modulepreload" crossorigin href="/static/assets/formControlState-C1XOL3mQ.js">
    <link rel="modulepreload" crossorigin href="/static/assets/SwitchBase-BdpsuNf_.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Button-DJ_uYab0.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Alert-M7jUzTjE.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Dialog-aanaDG86.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Container-vcG9JMyV.js">
    <link rel="modulepreload" crossorigin href="/static/assets/Link-4dUp4u44.js">
    <script type="module" crossorigin src="/static/assets/quiz_public-Cl9qe4Mg.js"></script>
{% endblock %}
