{% extends "emails/base.html" %}
{% load i18n %}
{% block extra_styles %}
    pre {
        background-color: #f4f4f4;
        padding: 10px;
        border-radius: 5px;
        overflow-x: auto;
    }
{% endblock %}

{% block content %}
        <h2 class="email-title">{{ lesson.title }}</h2>

        {{ lesson.content|safe }}

        <p class="email-muted-note">
            {% blocktranslate %}If you wish to unsubscribe from this course, please <a href="{{ unsubscribe_link }}" class="color-brand" style="text-decoration: none;">click here</a>{% endblocktranslate %}.
        </p>
{% endblock %}
