import{i as o,j as s}from"./render-D1ZqzUbP.js";const a=o(s.jsx("path",{d:"M5 13.18v4L12 21l7-3.82v-4L12 17zM12 3 1 9l11 6 9-4.91V17h2V9z"}));export{a as S};
//# sourceMappingURL=School-CRKHYOSN.js.map
