import{g as c,f as p,r as d,b as g,j as u,c as v,d as x,s as D,m as f,T as m}from"./render-D1ZqzUbP.js";import{a as T}from"./Dialog-aanaDG86.js";function y(o){return c("MuiDialogContent",o)}p("MuiDialogContent",["root","dividers"]);function M(o){return c("MuiDialogTitle",o)}const R=p("MuiDialogTitle",["root"]),w=o=>{const{classes:t,dividers:s}=o;return x({root:["root",s&&"dividers"]},y,t)},U=D("div",{name:"MuiDialogContent",slot:"Root",overridesResolver:(o,t)=>{const{ownerState:s}=o;return[t.root,s.dividers&&t.dividers]}})(f(({theme:o})=>({flex:"1 1 auto",WebkitOverflowScrolling:"touch",overflowY:"auto",padding:"20px 24px",variants:[{props:({ownerState:t})=>t.dividers,style:{padding:"16px 24px",borderTop:`1px solid ${(o.vars||o).palette.divider}`,borderBottom:`1px solid ${(o.vars||o).palette.divider}`}},{props:({ownerState:t})=>!t.dividers,style:{[`.${R.root} + &`]:{paddingTop:0}}}]}))),S=d.forwardRef(function(t,s){const e=g({props:t,name:"MuiDialogContent"}),{className:r,dividers:a=!1,...n}=e,i={...e,dividers:a},l=w(i);return u.jsx(U,{className:v(l.root,r),ownerState:i,ref:s,...n})}),b=o=>{const{classes:t}=o;return x({root:["root"]},M,t)},h=D(m,{name:"MuiDialogTitle",slot:"Root"})({padding:"16px 24px",flex:"0 0 auto"}),$=d.forwardRef(function(t,s){const e=g({props:t,name:"MuiDialogTitle"}),{className:r,id:a,...n}=e,i=e,l=b(i),{titleId:C=a}=d.useContext(T);return u.jsx(h,{component:"h2",className:v(l.root,r),ownerState:i,ref:s,variant:"h6",id:a??C,...n})});export{$ as D,S as a};
//# sourceMappingURL=DialogTitle-J__fqFcw.js.map
